==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/ca.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Falta la clau de recuperació de contrasenya",
    "Please repeat the recovery key password" : "Si us plau, repetiu la clau de recuperació de contrasenya",
    "Repeated recovery key password does not match the provided recovery key password" : "La contrasenya de la clau de recuperació repetida no coincideix amb la contrasenya de clau de recuperació proporcionada",
    "Recovery key successfully enabled" : "La clau de recuperació s'ha habilitat",
    "Could not enable recovery key. Please check your recovery key password!" : "No s'ha pogut habilitar la clau de recuperació. Comproveu contrasenya de la clau de recuperació!",
    "Recovery key successfully disabled" : "La clau de recuperació s'ha inhabilitat",
    "Could not disable recovery key. Please check your recovery key password!" : "No s'ha pogut inhabilitar la clau de recuperació. Comproveu la contrasenya de la clau de recuperació!",
    "Missing parameters" : "Falten paràmetres",
    "Please provide the old recovery password" : "Si us plau, proporcioneu la contrasenya de recuperació antiga",
    "Please provide a new recovery password" : "Si us plau, proporcioneu una nova contrasenya de recuperació",
    "Please repeat the new recovery password" : "Si us plau, repetiu la nova contrasenya de recuperació",
    "Password successfully changed." : "La contrasenya s'ha canviat.",
    "Could not change the password. Maybe the old password was not correct." : "No s'ha pogut canviar la contrasenya. Potser la contrasenya anterior no era correcta.",
    "Recovery Key disabled" : "Clau de recuperació inhabilitada",
    "Recovery Key enabled" : "Clau de recuperació habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "No es pot habilitar la clau de recuperació, torneu-ho a provar o poseu-vos en contacte amb l'administrador",
    "Could not update the private key password." : "No s'ha pogut actualitzar la contrasenya de la clau privada.",
    "The old password was not correct, please try again." : "La contrasenya antiga no és correcta, si us plau torneu-ho a provar.",
    "The current log-in password was not correct, please try again." : "La contrasenya d'inici de sessió actual no era correcta, si us plau torneu-ho a provar.",
    "Private key password successfully updated." : "La contrasenya de la clau privada s'ha actualitzat.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Clau privada no és vàlida per a l'aplicació de xifratge. Si us plau, actualitzeu la contrasenya de la clau privada als vostrses paràmetres personalz per recuperar l'accés als vostres fitxers xifrats.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "L'aplicació de xifratge està habilitada, però les vostres claus no s'han inicialitzat. Si us plau, tanqueu la sessió i torneu a iniciar la sessió.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Si us plau, activeu el xifratge del servidor als paràmetres de l'administrador per poder fer servir el mòdul de xifratge.",
    "Encryption app is enabled and ready" : "L'aplicació de xifratge està habilitada i preparada",
    "Bad Signature" : "Signatura incorrecta",
    "Missing Signature" : "Falta Signatura",
    "one-time password for server-side-encryption" : "contrasenya única per al xifratge en el servidor",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot desxifrar aquest fitxer, probablement és un fitxer compartit. Demaneu al propietari del fitxer que torni a compartir el fitxer amb vosaltres.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot llegir aquest fitxer, probablement aquest sigui un fitxer compartit. Demana al propietari del fitxer que torni a compartir el fitxer amb tu.",
    "Default encryption module" : "Mòdul de xifratge per defecte",
    "Default encryption module for server-side encryption" : "Mòdul criptogràfic per defecte per a xifratge de servidor",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'aplicació de xifratge està activada però les claus no estan inicialitzades, tanqueu la sessió i inicieu-ne una de nova.",
    "Encrypt the home storage" : "Xifra l'emmagatzematge de casa",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Si activeu aquesta opció, es xifraran tots els fitxers emmagatzemats a l’emmagatzematge principal; en cas contrari, només es xifraran els fitxers d’emmagatzematge extern",
    "Enable recovery key" : "Habilita la clau de recuperació",
    "Disable recovery key" : "Inhabilita la clau de recuperació",
    "Recovery key password" : "Clau de recuperació de la contrasenya",
    "Repeat recovery key password" : "Repetiu la contrasenya de la clau de recuperació",
    "Change recovery key password:" : "Canvia la clau de recuperació de contrasenya:",
    "Old recovery key password" : "Contrasenya antiga de clau de recuperació",
    "New recovery key password" : "Nova contrasenya de clau de recuperació",
    "Repeat new recovery key password" : "Repetiu la contrasenya de la clau de recuperació nova",
    "Change Password" : "Canvia la contrasenya",
    "Basic encryption module" : "Mòdul de xifratge bàsic",
    "Your private key password no longer matches your log-in password." : "La clau privada ja no es correspon amb la contrasenya d'inici de sessió:",
    "Set your old private key password to your current log-in password:" : "Establiu la vostra antiga clau privada a l'actual contrasenya d'accés:",
    "Old log-in password" : "Contrasenya antiga d’inici de sessió",
    "Current log-in password" : "Contrasenya actual d’inici de sessió",
    "Update Private Key Password" : "Actualitza la contrasenya de clau privada",
    "Enable password recovery:" : "Habilita la recuperació de contrasenya:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Si activeu aquesta opció, podreu accedir als vostres fitxers encriptats en cas de pèrdua de contrasenya",
    "Enabled" : "Habilitat",
    "Disabled" : "Inhabilitat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/ca.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Falta la clau de recuperació de contrasenya",
    "Please repeat the recovery key password" : "Si us plau, repetiu la clau de recuperació de contrasenya",
    "Repeated recovery key password does not match the provided recovery key password" : "La contrasenya de la clau de recuperació repetida no coincideix amb la contrasenya de clau de recuperació proporcionada",
    "Recovery key successfully enabled" : "La clau de recuperació s'ha habilitat",
    "Could not enable recovery key. Please check your recovery key password!" : "No s'ha pogut habilitar la clau de recuperació. Comproveu contrasenya de la clau de recuperació!",
    "Recovery key successfully disabled" : "La clau de recuperació s'ha inhabilitat",
    "Could not disable recovery key. Please check your recovery key password!" : "No s'ha pogut inhabilitar la clau de recuperació. Comproveu la contrasenya de la clau de recuperació!",
    "Missing parameters" : "Falten paràmetres",
    "Please provide the old recovery password" : "Si us plau, proporcioneu la contrasenya de recuperació antiga",
    "Please provide a new recovery password" : "Si us plau, proporcioneu una nova contrasenya de recuperació",
    "Please repeat the new recovery password" : "Si us plau, repetiu la nova contrasenya de recuperació",
    "Password successfully changed." : "La contrasenya s'ha canviat.",
    "Could not change the password. Maybe the old password was not correct." : "No s'ha pogut canviar la contrasenya. Potser la contrasenya anterior no era correcta.",
    "Recovery Key disabled" : "Clau de recuperació inhabilitada",
    "Recovery Key enabled" : "Clau de recuperació habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "No es pot habilitar la clau de recuperació, torneu-ho a provar o poseu-vos en contacte amb l'administrador",
    "Could not update the private key password." : "No s'ha pogut actualitzar la contrasenya de la clau privada.",
    "The old password was not correct, please try again." : "La contrasenya antiga no és correcta, si us plau torneu-ho a provar.",
    "The current log-in password was not correct, please try again." : "La contrasenya d'inici de sessió actual no era correcta, si us plau torneu-ho a provar.",
    "Private key password successfully updated." : "La contrasenya de la clau privada s'ha actualitzat.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Clau privada no és vàlida per a l'aplicació de xifratge. Si us plau, actualitzeu la contrasenya de la clau privada als vostrses paràmetres personalz per recuperar l'accés als vostres fitxers xifrats.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "L'aplicació de xifratge està habilitada, però les vostres claus no s'han inicialitzat. Si us plau, tanqueu la sessió i torneu a iniciar la sessió.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Si us plau, activeu el xifratge del servidor als paràmetres de l'administrador per poder fer servir el mòdul de xifratge.",
    "Encryption app is enabled and ready" : "L'aplicació de xifratge està habilitada i preparada",
    "Bad Signature" : "Signatura incorrecta",
    "Missing Signature" : "Falta Signatura",
    "one-time password for server-side-encryption" : "contrasenya única per al xifratge en el servidor",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot desxifrar aquest fitxer, probablement és un fitxer compartit. Demaneu al propietari del fitxer que torni a compartir el fitxer amb vosaltres.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es pot llegir aquest fitxer, probablement aquest sigui un fitxer compartit. Demana al propietari del fitxer que torni a compartir el fitxer amb tu.",
    "Default encryption module" : "Mòdul de xifratge per defecte",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'aplicació de xifratge està activada però les claus no estan inicialitzades, tanqueu la sessió i inicieu-ne una de nova.",
    "Encrypt the home storage" : "Xifra l'emmagatzematge de casa",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Si activeu aquesta opció, es xifraran tots els fitxers emmagatzemats a l’emmagatzematge principal; en cas contrari, només es xifraran els fitxers d’emmagatzematge extern",
    "Enable recovery key" : "Habilita la clau de recuperació",
    "Disable recovery key" : "Inhabilita la clau de recuperació",
    "Recovery key password" : "Clau de recuperació de la contrasenya",
    "Repeat recovery key password" : "Repetiu la contrasenya de la clau de recuperació",
    "Change recovery key password:" : "Canvia la clau de recuperació de contrasenya:",
    "Old recovery key password" : "Contrasenya antiga de clau de recuperació",
    "New recovery key password" : "Nova contrasenya de clau de recuperació",
    "Repeat new recovery key password" : "Repetiu la contrasenya de la clau de recuperació nova",
    "Change Password" : "Canvia la contrasenya",
    "Basic encryption module" : "Mòdul de xifratge bàsic",
    "Your private key password no longer matches your log-in password." : "La clau privada ja no es correspon amb la contrasenya d'inici de sessió:",
    "Set your old private key password to your current log-in password:" : "Establiu la vostra antiga clau privada a l'actual contrasenya d'accés:",
    "Old log-in password" : "Contrasenya antiga d’inici de sessió",
    "Current log-in password" : "Contrasenya actual d’inici de sessió",
    "Update Private Key Password" : "Actualitza la contrasenya de clau privada",
    "Enable password recovery:" : "Habilita la recuperació de contrasenya:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Si activeu aquesta opció, podreu accedir als vostres fitxers encriptats en cas de pèrdua de contrasenya",
    "Enabled" : "Habilitat",
    "Disabled" : "Inhabilitat",
    "Default encryption module for server-side encryption" : "Mòdul criptogràfic per defecte per a xifratge de servidor"
},
"nplurals=2; plural=(n != 1);");
